@@ -1,6 +1,6 @@
 import stat
 from os import chmod
-from os.path import join
+from os.path import join, isfile, sep
 
 from jinja2 import Environment, PackageLoader
 
@@ -13,13 +13,17 @@ class Debianize:
     def __init__(self, buildout, name, options):
         self.name, self.options = name, options
         self.bin = buildout['buildout']['bin-directory']
+        self.fpm_path = (self.bin + sep) if isfile(join(self.bin, 'fpm')) else ""
+        self.pip_path = (self.bin + sep) if isfile(join(self.bin, 'pip')) else ""
 
     def install(self):
         template = env.get_template('debianize.sh')
         output = template.render(
             follow_dependencies=self.options.get(
                 'follow_dependencies', '.*').split(),
-            maintainer=self.options.get('maintainer', None)
+            maintainer=self.options.get('maintainer', None),
+            pip_path=self.pip_path,
+            fpm_path=self.fpm_path
         )
         executable = join(self.bin, 'debianize')
         with open(executable, 'w') as fh:
